@@ -39,7 +39,7 @@ public:
     Private()
         : model(0, 3)
     {
-        QStandardItem *headerItem = new QStandardItem(i18nc("Header text for IPv6 address", "Address"));
+        auto headerItem = new QStandardItem(i18nc("Header text for IPv6 address", "Address"));
         model.setHorizontalHeaderItem(0, headerItem);
         headerItem = new QStandardItem(i18nc("Header text for IPv6 prefix", "Prefix"));
         model.setHorizontalHeaderItem(1, headerItem);
@@ -60,8 +60,8 @@ IPv6Widget::IPv6Widget(const NetworkManager::Setting::Ptr &setting, QWidget *par
     m_ui->tableViewAddresses->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
     m_ui->tableViewAddresses->horizontalHeader()->setStretchLastSection(true);
 
-    IpV6Delegate *ipDelegate = new IpV6Delegate(this);
-    IntDelegate *prefixDelegate = new IntDelegate(0, 128, this);
+    auto ipDelegate = new IpV6Delegate(this);
+    auto prefixDelegate = new IntDelegate(0, 128, this);
     m_ui->tableViewAddresses->setItemDelegateForColumn(0, ipDelegate);
     m_ui->tableViewAddresses->setItemDelegateForColumn(1, prefixDelegate);
     m_ui->tableViewAddresses->setItemDelegateForColumn(2, ipDelegate);
@@ -152,8 +152,8 @@ void IPv6Widget::loadConfig(const NetworkManager::Setting::Ptr &setting)
     for (const QHostAddress &addr : ipv6Setting->dns()) {
         tmp.append(addr.toString());
     }
-    m_ui->dns->setText(tmp.join(","));
-    m_ui->dnsSearch->setText(ipv6Setting->dnsSearch().join(","));
+    m_ui->dns->setText(tmp.join(QStringLiteral(",")));
+    m_ui->dnsSearch->setText(ipv6Setting->dnsSearch().join(QStringLiteral(",")));
 
     // addresses
     for (const NetworkManager::IpAddress &address : ipv6Setting->addresses()) {
@@ -216,7 +216,7 @@ QVariantMap IPv6Widget::setting() const
 
     // dns
     if (m_ui->dns->isEnabled() && !m_ui->dns->text().isEmpty()) {
-        QStringList tmp = m_ui->dns->text().split(',');
+        QStringList tmp = m_ui->dns->text().split(QLatin1Char(','));
         QList<QHostAddress> tmpAddrList;
         for (const QString &str : tmp) {
             QHostAddress addr(str);
@@ -226,7 +226,7 @@ QVariantMap IPv6Widget::setting() const
         ipv6Setting.setDns(tmpAddrList);
     }
     if (m_ui->dnsSearch->isEnabled() && !m_ui->dnsSearch->text().isEmpty()) {
-        ipv6Setting.setDnsSearch(m_ui->dnsSearch->text().split(','));
+        ipv6Setting.setDnsSearch(m_ui->dnsSearch->text().split(QLatin1Char(',')));
     }
 
     // addresses
@@ -407,16 +407,16 @@ void IPv6Widget::slotDnsServers()
     QPointer<QDialog> dialog = new QDialog(this);
     dialog->setWindowTitle(i18n("Edit DNS servers"));
     dialog->setLayout(new QVBoxLayout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
+    auto buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
     connect(buttons, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
-    KEditListWidget *listWidget = new KEditListWidget(dialog);
-    listWidget->setItems(m_ui->dns->text().split(',').replaceInStrings(" ", ""));
+    auto listWidget = new KEditListWidget(dialog);
+    listWidget->setItems(m_ui->dns->text().split(QLatin1Char(',')).replaceInStrings(QStringLiteral(" "), QLatin1String("")));
     listWidget->lineEdit()->setFocus(Qt::OtherFocusReason);
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
     connect(dialog.data(), &QDialog::accepted, [listWidget, this]() {
-        QString text = listWidget->items().join(",");
+        QString text = listWidget->items().join(QStringLiteral(","));
         if (text.endsWith(',')) {
             text.chop(1);
         }
@@ -436,16 +436,16 @@ void IPv6Widget::slotDnsDomains()
     QPointer<QDialog> dialog = new QDialog(this);
     dialog->setWindowTitle(i18n("Edit DNS search domains"));
     dialog->setLayout(new QVBoxLayout);
-    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
+    auto buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, dialog);
     connect(buttons, &QDialogButtonBox::accepted, dialog.data(), &QDialog::accept);
     connect(buttons, &QDialogButtonBox::rejected, dialog.data(), &QDialog::reject);
-    KEditListWidget *listWidget = new KEditListWidget(dialog);
-    listWidget->setItems(m_ui->dnsSearch->text().split(',').replaceInStrings(" ", ""));
+    auto listWidget = new KEditListWidget(dialog);
+    listWidget->setItems(m_ui->dnsSearch->text().split(QLatin1Char(',')).replaceInStrings(QStringLiteral(" "), QLatin1String("")));
     listWidget->lineEdit()->setFocus(Qt::OtherFocusReason);
     dialog->layout()->addWidget(listWidget);
     dialog->layout()->addWidget(buttons);
     connect(dialog.data(), &QDialog::accepted, [listWidget, this]() {
-        QString text = listWidget->items().join(",");
+        QString text = listWidget->items().join(QStringLiteral(","));
         if (text.endsWith(',')) {
             text.chop(1);
         }
@@ -480,7 +480,7 @@ bool IPv6Widget::isValid() const
 
     if (!m_ui->dns->text().isEmpty()
         && (m_ui->method->currentIndex() == Automatic || m_ui->method->currentIndex() == Manual || m_ui->method->currentIndex() == AutomaticOnlyIP)) {
-        const QStringList tmp = m_ui->dns->text().split(',');
+        const QStringList tmp = m_ui->dns->text().split(QLatin1Char(','));
         for (const QString &str : tmp) {
             QHostAddress addr(str);
             if (addr.isNull()) {
